Changelog
=========


(unreleased)
------------
- Remove tests for win. [chao.bi]
- Fix build errors. [chao.bi]
- Add mysql_db_profiler. [chao.bi]
- Merge branch 'main' of https://github.com/hgbink/spark-jdbc-profiler.
  [chao.bi]
- Update README.md. [Chao Bi]
- Remove sponsor button. [chao.bi]
- ✅ Ready to clone and code. [hgbink]
- Initial commit. [Chao Bi]


